@@ -3,6 +3,8 @@
 package flags
 
 import (
+	"time"
+
 	"github.com/spf13/viper"
 )
 
@@ -22,6 +24,10 @@ func LockTimeout() int {
 	return viper.GetInt("LOCK_TIMEOUT")
 }
 
+func BackfillBatchSize() int { return viper.GetInt("BACKFILL_BATCH_SIZE") }
+
+func BackfillBatchDelay() time.Duration { return viper.GetDuration("BACKFILL_BATCH_DELAY") }
+
 func Role() string {
 	return viper.GetString("ROLE")
 }
