@@ -54,8 +54,8 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "reviews",
 							Column: "rating",
 							Type:   ptr("integer"),
-							Up:     ptr("CAST (rating AS integer)"),
-							Down:   ptr("CAST (rating AS text)"),
+							Up:     "CAST (rating AS integer)",
+							Down:   "CAST (rating AS text)",
 						},
 					},
 				},
@@ -190,9 +190,10 @@ func TestChangeColumnType(t *testing.T) {
 									Name: "department_id",
 									Type: "integer",
 									References: &migrations.ForeignKeyReference{
-										Name:   "fk_employee_department",
-										Table:  "departments",
-										Column: "id",
+										Name:     "fk_employee_department",
+										Table:    "departments",
+										Column:   "id",
+										OnDelete: migrations.ForeignKeyReferenceOnDeleteCASCADE,
 									},
 								},
 							},
@@ -206,25 +207,90 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "employees",
 							Column: "department_id",
 							Type:   ptr("bigint"),
-							Up:     ptr("department_id"),
-							Down:   ptr("department_id"),
+							Up:     "department_id",
+							Down:   "department_id",
 						},
 					},
 				},
 			},
 			afterStart: func(t *testing.T, db *sql.DB, schema string) {
 				// A temporary FK constraint has been created on the temporary column
-				ValidatedForeignKeyMustExist(t, db, schema, "employees", migrations.DuplicationName("fk_employee_department"))
+				ValidatedForeignKeyMustExist(t, db, schema, "employees", migrations.DuplicationName("fk_employee_department"), withOnDeleteCascade())
 			},
 			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 			},
 			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint still exists on the column
-				ValidatedForeignKeyMustExist(t, db, schema, "employees", "fk_employee_department")
+				ValidatedForeignKeyMustExist(t, db, schema, "employees", "fk_employee_department", withOnDeleteCascade())
 			},
 		},
 		{
-			name: "changing column type preserves any defaults on the column",
+			name: "changing column type removes any incompatible defaults on the column",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "users",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "integer",
+									Pk:   ptr(true),
+								},
+								{
+									Name:     "age",
+									Type:     "text",
+									Default:  ptr("'0'"),
+									Nullable: ptr(true),
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_change_type",
+					Operations: migrations.Operations{
+						&migrations.OpAlterColumn{
+							Table:  "users",
+							Column: "age",
+							Type:   ptr("integer"),
+							Up:     "CAST(age AS integer)",
+							Down:   "CAST(age AS text)",
+						},
+					},
+				},
+			},
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// A row can be inserted into the new version of the table.
+				MustInsert(t, db, schema, "02_change_type", "users", map[string]string{
+					"id": "1",
+				})
+
+				// The newly inserted row contains a NULL instead of the old default value.
+				rows := MustSelect(t, db, schema, "02_change_type", "users")
+				assert.Equal(t, []map[string]any{
+					{"id": 1, "age": nil},
+				}, rows)
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// A row can be inserted into the new version of the table.
+				MustInsert(t, db, schema, "02_change_type", "users", map[string]string{
+					"id": "2",
+				})
+
+				// The newly inserted row contains a NULL instead of the old default value.
+				rows := MustSelect(t, db, schema, "02_change_type", "users")
+				assert.Equal(t, []map[string]any{
+					{"id": 1, "age": nil},
+					{"id": 2, "age": nil},
+				}, rows)
+			},
+		},
+		{
+			name: "changing column type preserves any compatible defaults on the column",
 			migrations: []migrations.Migration{
 				{
 					Name: "01_add_table",
@@ -254,8 +320,8 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "users",
 							Column: "username",
 							Type:   ptr("varchar(255)"),
-							Up:     ptr("username"),
-							Down:   ptr("username"),
+							Up:     "username",
+							Down:   "username",
 						},
 					},
 				},
@@ -289,7 +355,66 @@ func TestChangeColumnType(t *testing.T) {
 			},
 		},
 		{
-			name: "changing column type preserves any check constraints on the column",
+			name: "changing column type removes any incompatile check constraints on the column",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "users",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "integer",
+									Pk:   ptr(true),
+								},
+								{
+									Name:     "age",
+									Type:     "text",
+									Nullable: ptr(true),
+									Check: &migrations.CheckConstraint{
+										Name:       "age_length",
+										Constraint: "length(age) < 3",
+									},
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_change_type",
+					Operations: migrations.Operations{
+						&migrations.OpAlterColumn{
+							Table:  "users",
+							Column: "age",
+							Type:   ptr("integer"),
+							Up:     "CAST(age AS integer)",
+							Down:   "(SELECT CASE WHEN age < 100 THEN age::text ELSE '0' END)",
+						},
+					},
+				},
+			},
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// Inserting a row into the new schema that violates the check
+				// constraint on the old schema should succeed.
+				MustInsert(t, db, schema, "02_change_type", "users", map[string]string{
+					"id":  "1",
+					"age": "1111",
+				})
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// Inserting a row into the new schema that violates the check
+				// constraint on the old schema should succeed.
+				MustInsert(t, db, schema, "02_change_type", "users", map[string]string{
+					"id":  "2",
+					"age": "2222",
+				})
+			},
+		},
+		{
+			name: "changing column type preserves any compatible check constraints on the column",
 			migrations: []migrations.Migration{
 				{
 					Name: "01_add_table",
@@ -322,8 +447,8 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "users",
 							Column: "username",
 							Type:   ptr("varchar(255)"),
-							Up:     ptr("username"),
-							Down:   ptr("username"),
+							Up:     "username",
+							Down:   "username",
 						},
 					},
 				},
@@ -375,8 +500,8 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "users",
 							Column: "username",
 							Type:   ptr("varchar(255)"),
-							Up:     ptr("username"),
-							Down:   ptr("username"),
+							Up:     "username",
+							Down:   "username",
 						},
 					},
 				},
@@ -425,8 +550,8 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "users",
 							Column: "username",
 							Unique: &migrations.UniqueConstraint{Name: "unique_username"},
-							Up:     ptr("username"),
-							Down:   ptr("username"),
+							Up:     "username",
+							Down:   "username",
 						},
 					},
 				},
@@ -437,8 +562,8 @@ func TestChangeColumnType(t *testing.T) {
 							Table:  "users",
 							Column: "username",
 							Type:   ptr("varchar(255)"),
-							Up:     ptr("username"),
-							Down:   ptr("username"),
+							Up:     "username",
+							Down:   "username",
 						},
 					},
 				},
@@ -471,6 +596,53 @@ func TestChangeColumnType(t *testing.T) {
 				})
 			},
 		},
+		{
+			name: "changing column type preserves any comments on the column",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "users",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
+								},
+								{
+									Name:    "username",
+									Type:    "text",
+									Comment: ptr("the name of the user"),
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_change_type",
+					Operations: migrations.Operations{
+						&migrations.OpAlterColumn{
+							Table:  "users",
+							Column: "username",
+							Type:   ptr("varchar(255)"),
+							Up:     "username",
+							Down:   "username",
+						},
+					},
+				},
+			},
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// The duplicated column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "users", migrations.TemporaryName("username"), "the name of the user")
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// The final column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "users", "username", "the name of the user")
+			},
+		},
 	})
 }
 
@@ -517,7 +689,7 @@ func TestChangeColumnTypeValidation(t *testing.T) {
 							Table:  "reviews",
 							Column: "rating",
 							Type:   ptr("integer"),
-							Down:   ptr("CAST (rating AS text)"),
+							Down:   "CAST (rating AS text)",
 						},
 					},
 				},
@@ -535,7 +707,7 @@ func TestChangeColumnTypeValidation(t *testing.T) {
 							Table:  "reviews",
 							Column: "rating",
 							Type:   ptr("integer"),
-							Up:     ptr("CAST (rating AS integer)"),
+							Up:     "CAST (rating AS integer)",
 						},
 					},
 				},
