@@ -9,6 +9,7 @@ import (
 	"github.com/xataio/pgroll/pkg/schema"
 )
 
+// OpDropNotNull is an operation that drops the NOT NULL constraint from a column
 type OpDropNotNull struct {
 	Table  string `json:"table"`
 	Column string `json:"column"`
@@ -18,7 +19,7 @@ type OpDropNotNull struct {
 
 var _ Operation = (*OpDropNotNull)(nil)
 
-func (o *OpDropNotNull) Start(ctx context.Context, conn db.DB, stateSchema string, tr SQLTransformer, s *schema.Schema, cbs ...CallbackFn) (*schema.Table, error) {
+func (o *OpDropNotNull) Start(ctx context.Context, conn db.DB, latestSchema string, tr SQLTransformer, s *schema.Schema, cbs ...CallbackFn) (*schema.Table, error) {
 	table := s.GetTable(o.Table)
 
 	return table, nil
