@@ -55,7 +55,7 @@ func TestDropNotNull(t *testing.T) {
 							Table:    "reviews",
 							Column:   "review",
 							Nullable: ptr(true),
-							Down:     ptr("(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)"),
+							Down:     "(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)",
 						},
 					},
 				},
@@ -191,8 +191,8 @@ func TestDropNotNull(t *testing.T) {
 							Table:    "reviews",
 							Column:   "review",
 							Nullable: ptr(true),
-							Down:     ptr("(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)"),
-							Up:       ptr("review || ' (from the old column)'"),
+							Down:     "(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)",
+							Up:       "review || ' (from the old column)'",
 						},
 					},
 				},
@@ -277,8 +277,8 @@ func TestDropNotNull(t *testing.T) {
 							Table:    "employees",
 							Column:   "department_id",
 							Nullable: ptr(true),
-							Down:     ptr("(SELECT CASE WHEN department_id IS NULL THEN 1 ELSE department_id END)"),
-							Up:       ptr("department_id"),
+							Down:     "(SELECT CASE WHEN department_id IS NULL THEN 1 ELSE department_id END)",
+							Up:       "department_id",
 						},
 					},
 				},
@@ -325,8 +325,8 @@ func TestDropNotNull(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(true),
-							Up:       ptr("name"),
-							Down:     ptr("(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)"),
+							Up:       "name",
+							Down:     "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
 						},
 					},
 				},
@@ -393,8 +393,8 @@ func TestDropNotNull(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(true),
-							Up:       ptr("name"),
-							Down:     ptr("(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)"),
+							Up:       "name",
+							Down:     "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
 						},
 					},
 				},
@@ -446,8 +446,8 @@ func TestDropNotNull(t *testing.T) {
 							Table:  "users",
 							Column: "name",
 							Unique: &migrations.UniqueConstraint{Name: "unique_name"},
-							Up:     ptr("name"),
-							Down:   ptr("name"),
+							Up:     "name",
+							Down:   "name",
 						},
 					},
 				},
@@ -458,8 +458,8 @@ func TestDropNotNull(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(true),
-							Up:       ptr("name"),
-							Down:     ptr("(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)"),
+							Up:       "name",
+							Down:     "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
 						},
 					},
 				},
@@ -492,6 +492,54 @@ func TestDropNotNull(t *testing.T) {
 				})
 			},
 		},
+		{
+			name: "dropping not null retains any comments defined on the column",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "users",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
+								},
+								{
+									Name:     "name",
+									Type:     "text",
+									Nullable: ptr(false),
+									Comment:  ptr("the name of the user"),
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_set_not_null",
+					Operations: migrations.Operations{
+						&migrations.OpAlterColumn{
+							Table:    "users",
+							Column:   "name",
+							Nullable: ptr(true),
+							Up:       "name",
+							Down:     "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
+						},
+					},
+				},
+			},
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// The duplicated column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "users", migrations.TemporaryName("name"), "the name of the user")
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// The final column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "users", "name", "the name of the user")
+			},
+		},
 	})
 }
 
@@ -529,7 +577,7 @@ func TestDropNotNullValidation(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(true),
-							Up:       ptr("name"),
+							Up:       "name",
 						},
 					},
 				},
@@ -566,8 +614,8 @@ func TestDropNotNullValidation(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(true),
-							Up:       ptr("name"),
-							Down:     ptr("(SELECT CASE WHEN name IS NULL THEN 'placeholder' ELSE name END)"),
+							Up:       "name",
+							Down:     "(SELECT CASE WHEN name IS NULL THEN 'placeholder' ELSE name END)",
 						},
 					},
 				},
