@@ -11,7 +11,7 @@ import (
 
 var _ Operation = (*OpRawSQL)(nil)
 
-func (o *OpRawSQL) Start(ctx context.Context, conn db.DB, stateSchema string, tr SQLTransformer, s *schema.Schema, cbs ...CallbackFn) (*schema.Table, error) {
+func (o *OpRawSQL) Start(ctx context.Context, conn db.DB, latestSchema string, tr SQLTransformer, s *schema.Schema, cbs ...CallbackFn) (*schema.Table, error) {
 	if o.OnComplete {
 		return nil, nil
 	}
@@ -65,6 +65,7 @@ func (o *OpRawSQL) Validate(ctx context.Context, s *schema.Schema) error {
 	return nil
 }
 
+// IsIsolated returns true if the operation is isolated and should be run with other operations.
 func (o *OpRawSQL) IsIsolated() bool {
 	return !o.OnComplete
 }
