@@ -47,8 +47,8 @@ func TestSetCheckConstraint(t *testing.T) {
 								Name:       "check_title_length",
 								Constraint: "length(title) > 3",
 							},
-							Up:   ptr("(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)"),
-							Down: ptr("title"),
+							Up:   "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
+							Down: "title",
 						},
 					},
 				},
@@ -180,8 +180,8 @@ func TestSetCheckConstraint(t *testing.T) {
 								Name:       "check_title_length",
 								Constraint: "length(title) > 3",
 							},
-							Up:   ptr("(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)"),
-							Down: ptr("title"),
+							Up:   "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
+							Down: "title",
 						},
 					},
 				},
@@ -258,9 +258,10 @@ func TestSetCheckConstraint(t *testing.T) {
 									Type:     "integer",
 									Nullable: ptr(true),
 									References: &migrations.ForeignKeyReference{
-										Name:   "fk_employee_department",
-										Table:  "departments",
-										Column: "id",
+										Name:     "fk_employee_department",
+										Table:    "departments",
+										Column:   "id",
+										OnDelete: migrations.ForeignKeyReferenceOnDeleteCASCADE,
 									},
 								},
 							},
@@ -277,21 +278,21 @@ func TestSetCheckConstraint(t *testing.T) {
 								Name:       "check_valid_department_id",
 								Constraint: "department_id > 1",
 							},
-							Up:   ptr("(SELECT CASE WHEN department_id <= 1 THEN 2 ELSE department_id END)"),
-							Down: ptr("department_id"),
+							Up:   "(SELECT CASE WHEN department_id <= 1 THEN 2 ELSE department_id END)",
+							Down: "department_id",
 						},
 					},
 				},
 			},
 			afterStart: func(t *testing.T, db *sql.DB, schema string) {
 				// A temporary FK constraint has been created on the temporary column
-				ValidatedForeignKeyMustExist(t, db, schema, "employees", migrations.DuplicationName("fk_employee_department"))
+				ValidatedForeignKeyMustExist(t, db, schema, "employees", migrations.DuplicationName("fk_employee_department"), withOnDeleteCascade())
 			},
 			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 			},
 			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint still exists on the column
-				ValidatedForeignKeyMustExist(t, db, schema, "employees", "fk_employee_department")
+				ValidatedForeignKeyMustExist(t, db, schema, "employees", "fk_employee_department", withOnDeleteCascade())
 			},
 		},
 		{
@@ -334,8 +335,8 @@ func TestSetCheckConstraint(t *testing.T) {
 								Name:       "check_body_length",
 								Constraint: "length(body) > 3",
 							},
-							Up:   ptr("(SELECT CASE WHEN length(body) <= 3 THEN LPAD(body, 4, '-') ELSE body END)"),
-							Down: ptr("body"),
+							Up:   "(SELECT CASE WHEN length(body) <= 3 THEN LPAD(body, 4, '-') ELSE body END)",
+							Down: "body",
 						},
 					},
 				},
@@ -392,8 +393,8 @@ func TestSetCheckConstraint(t *testing.T) {
 								Name:       "check_title_length",
 								Constraint: "length(title) > 3",
 							},
-							Up:   ptr("(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)"),
-							Down: ptr("title"),
+							Up:   "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
+							Down: "title",
 						},
 					},
 				},
@@ -442,8 +443,8 @@ func TestSetCheckConstraint(t *testing.T) {
 							Table:  "posts",
 							Column: "title",
 							Unique: &migrations.UniqueConstraint{Name: "unique_title"},
-							Up:     ptr("title"),
-							Down:   ptr("title"),
+							Up:     "title",
+							Down:   "title",
 						},
 					},
 				},
@@ -457,8 +458,8 @@ func TestSetCheckConstraint(t *testing.T) {
 								Name:       "check_title_length",
 								Constraint: "length(title) > 3",
 							},
-							Up:   ptr("(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)"),
-							Down: ptr("title"),
+							Up:   "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
+							Down: "title",
 						},
 					},
 				},
@@ -491,6 +492,56 @@ func TestSetCheckConstraint(t *testing.T) {
 				})
 			},
 		},
+		{
+			name: "comments are preserved when adding a check constraint",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "posts",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
+								},
+								{
+									Name:    "title",
+									Type:    "text",
+									Comment: ptr("the title of the post"),
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_add_check_constraint",
+					Operations: migrations.Operations{
+						&migrations.OpAlterColumn{
+							Table:  "posts",
+							Column: "title",
+							Check: &migrations.CheckConstraint{
+								Name:       "check_title_length",
+								Constraint: "length(title) > 3",
+							},
+							Up:   "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
+							Down: "title",
+						},
+					},
+				},
+			},
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// The duplicated column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "posts", migrations.TemporaryName("title"), "the title of the post")
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// The final column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "posts", "title", "the title of the post")
+			},
+		},
 	})
 }
 
@@ -531,8 +582,8 @@ func TestSetCheckConstraintValidation(t *testing.T) {
 							Check: &migrations.CheckConstraint{
 								Constraint: "length(title) > 3",
 							},
-							Up:   ptr("(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)"),
-							Down: ptr("title"),
+							Up:   "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
+							Down: "title",
 						},
 					},
 				},
@@ -553,7 +604,7 @@ func TestSetCheckConstraintValidation(t *testing.T) {
 								Name:       "check_title_length",
 								Constraint: "length(title) > 3",
 							},
-							Down: ptr("title"),
+							Down: "title",
 						},
 					},
 				},
@@ -574,7 +625,7 @@ func TestSetCheckConstraintValidation(t *testing.T) {
 								Name:       "check_title_length",
 								Constraint: "length(title) > 3",
 							},
-							Up: ptr("(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)"),
+							Up: "(SELECT CASE WHEN length(title) <= 3 THEN LPAD(title, 4, '-') ELSE title END)",
 						},
 					},
 				},
