@@ -55,7 +55,7 @@ func TestSetNotNull(t *testing.T) {
 							Table:    "reviews",
 							Column:   "review",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)"),
+							Up:       "(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)",
 						},
 					},
 				},
@@ -197,8 +197,8 @@ func TestSetNotNull(t *testing.T) {
 							Table:    "reviews",
 							Column:   "review",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)"),
-							Down:     ptr("review || ' (from new column)'"),
+							Up:       "(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)",
+							Down:     "review || ' (from new column)'",
 						},
 					},
 				},
@@ -267,9 +267,10 @@ func TestSetNotNull(t *testing.T) {
 									Type:     "integer",
 									Nullable: ptr(true),
 									References: &migrations.ForeignKeyReference{
-										Name:   "fk_employee_department",
-										Table:  "departments",
-										Column: "id",
+										Name:     "fk_employee_department",
+										Table:    "departments",
+										Column:   "id",
+										OnDelete: migrations.ForeignKeyReferenceOnDeleteCASCADE,
 									},
 								},
 							},
@@ -283,21 +284,21 @@ func TestSetNotNull(t *testing.T) {
 							Table:    "employees",
 							Column:   "department_id",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN department_id IS NULL THEN 1 ELSE department_id END)"),
-							Down:     ptr("department_id"),
+							Up:       "(SELECT CASE WHEN department_id IS NULL THEN 1 ELSE department_id END)",
+							Down:     "department_id",
 						},
 					},
 				},
 			},
 			afterStart: func(t *testing.T, db *sql.DB, schema string) {
 				// A temporary FK constraint has been created on the temporary column
-				ValidatedForeignKeyMustExist(t, db, schema, "employees", migrations.DuplicationName("fk_employee_department"))
+				ValidatedForeignKeyMustExist(t, db, schema, "employees", migrations.DuplicationName("fk_employee_department"), withOnDeleteCascade())
 			},
 			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
 			},
 			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
 				// The foreign key constraint still exists on the column
-				ValidatedForeignKeyMustExist(t, db, schema, "employees", "fk_employee_department")
+				ValidatedForeignKeyMustExist(t, db, schema, "employees", "fk_employee_department", withOnDeleteCascade())
 			},
 		},
 		{
@@ -331,7 +332,7 @@ func TestSetNotNull(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)"),
+							Up:       "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
 						},
 					},
 				},
@@ -398,7 +399,7 @@ func TestSetNotNull(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)"),
+							Up:       "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
 						},
 					},
 				},
@@ -450,8 +451,8 @@ func TestSetNotNull(t *testing.T) {
 							Table:  "users",
 							Column: "name",
 							Unique: &migrations.UniqueConstraint{Name: "unique_name"},
-							Up:     ptr("name"),
-							Down:   ptr("name"),
+							Up:     "name",
+							Down:   "name",
 						},
 					},
 				},
@@ -462,7 +463,7 @@ func TestSetNotNull(t *testing.T) {
 							Table:    "users",
 							Column:   "name",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)"),
+							Up:       "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
 						},
 					},
 				},
@@ -495,6 +496,53 @@ func TestSetNotNull(t *testing.T) {
 				})
 			},
 		},
+		{
+			name: "setting a column to not null retains any comment defined on the column",
+			migrations: []migrations.Migration{
+				{
+					Name: "01_add_table",
+					Operations: migrations.Operations{
+						&migrations.OpCreateTable{
+							Name: "users",
+							Columns: []migrations.Column{
+								{
+									Name: "id",
+									Type: "serial",
+									Pk:   ptr(true),
+								},
+								{
+									Name:     "name",
+									Type:     "text",
+									Nullable: ptr(true),
+									Comment:  ptr("the name of the user"),
+								},
+							},
+						},
+					},
+				},
+				{
+					Name: "02_set_not_null",
+					Operations: migrations.Operations{
+						&migrations.OpAlterColumn{
+							Table:    "users",
+							Column:   "name",
+							Nullable: ptr(false),
+							Up:       "(SELECT CASE WHEN name IS NULL THEN 'anonymous' ELSE name END)",
+						},
+					},
+				},
+			},
+			afterStart: func(t *testing.T, db *sql.DB, schema string) {
+				// The duplicated column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "users", migrations.TemporaryName("name"), "the name of the user")
+			},
+			afterRollback: func(t *testing.T, db *sql.DB, schema string) {
+			},
+			afterComplete: func(t *testing.T, db *sql.DB, schema string) {
+				// The final column has a comment defined on it
+				ColumnMustHaveComment(t, db, schema, "users", "name", "the name of the user")
+			},
+		},
 	})
 }
 
@@ -544,7 +592,7 @@ func TestSetNotNullValidation(t *testing.T) {
 							Table:    "reviews",
 							Column:   "review",
 							Nullable: ptr(false),
-							Down:     ptr("review"),
+							Down:     "review",
 						},
 					},
 				},
@@ -591,8 +639,8 @@ func TestSetNotNullValidation(t *testing.T) {
 							Table:    "reviews",
 							Column:   "review",
 							Nullable: ptr(false),
-							Up:       ptr("(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)"),
-							Down:     ptr("review"),
+							Up:       "(SELECT CASE WHEN review IS NULL THEN product || ' is good' ELSE review END)",
+							Down:     "review",
 						},
 					},
 				},
