@@ -155,6 +155,54 @@ func TestPreviousVersionIsDroppedAfterMigrationCompletion(t *testing.T) {
 	})
 }
 
+func TestNoVersionSchemaForRawSQLMigrationsOptionIsRespected(t *testing.T) {
+	t.Parallel()
+
+	opts := []roll.Option{roll.WithNoVersionSchemaForRawSQL()}
+
+	testutils.WithMigratorAndStateAndConnectionToContainerWithOptions(t, opts, func(mig *roll.Roll, st *state.State, db *sql.DB) {
+		ctx := context.Background()
+
+		// Apply a create table migration
+		err := mig.Start(ctx, &migrations.Migration{Name: "01_create_table", Operations: migrations.Operations{createTableOp("table1")}})
+		require.NoError(t, err)
+		err = mig.Complete(ctx)
+		require.NoError(t, err)
+
+		// Apply a raw SQL migration - no version schema should be created for this version
+		err = mig.Start(ctx, &migrations.Migration{
+			Name: "02_create_table",
+			Operations: migrations.Operations{&migrations.OpRawSQL{
+				Up: "CREATE TABLE table2(a int)",
+			}},
+		})
+		require.NoError(t, err)
+		err = mig.Complete(ctx)
+		require.NoError(t, err)
+
+		// Start a third create table migration
+		err = mig.Start(ctx, &migrations.Migration{Name: "03_create_table", Operations: migrations.Operations{createTableOp("table3")}})
+		require.NoError(t, err)
+
+		// The previous version is migration 01 because there is no version schema
+		// for migration 02 due to the `WithNoVersionSchemaForRawSQL` option
+		prevVersion, err := st.PreviousVersion(ctx, "public")
+		require.NoError(t, err)
+		require.NotNil(t, prevVersion)
+		assert.Equal(t, "01_create_table", *prevVersion)
+
+		// Complete the third migration
+		err = mig.Complete(ctx)
+		require.NoError(t, err)
+
+		// The latest version version is migration 03
+		latestVersion, err := st.LatestVersion(ctx, "public")
+		require.NoError(t, err)
+		require.NotNil(t, latestVersion)
+		assert.Equal(t, "03_create_table", *latestVersion)
+	})
+}
+
 func TestSchemaIsDroppedAfterMigrationRollback(t *testing.T) {
 	t.Parallel()
 
@@ -589,6 +637,45 @@ func TestMigrationHooksAreInvoked(t *testing.T) {
 	})
 }
 
+func TestCallbacksAreInvokedOnMigrationStart(t *testing.T) {
+	t.Parallel()
+
+	testutils.WithMigratorAndConnectionToContainer(t, func(mig *roll.Roll, db *sql.DB) {
+		ctx := context.Background()
+
+		// Create a table
+		_, err := db.ExecContext(ctx, "CREATE TABLE users (id SERIAL PRIMARY KEY, name text)")
+		require.NoError(t, err)
+
+		// Insert some data
+		_, err = db.ExecContext(ctx,
+			"INSERT INTO users (id, name) VALUES (1, 'alice'), (2, 'bob')")
+		require.NoError(t, err)
+
+		// Define a mock callback
+		invoked := false
+		cb := func(n int64) { invoked = true }
+
+		// Start a migration that requires a backfill
+		err = mig.Start(ctx, &migrations.Migration{
+			Name: "02_change_type",
+			Operations: migrations.Operations{
+				&migrations.OpAlterColumn{
+					Table:  "users",
+					Column: "name",
+					Type:   ptr("varchar(255)"),
+					Up:     "name",
+					Down:   "name",
+				},
+			},
+		}, cb)
+		require.NoError(t, err)
+
+		// Ensure that the callback was invoked
+		assert.True(t, invoked)
+	})
+}
+
 func TestRollSchemaMethodReturnsCorrectSchema(t *testing.T) {
 	t.Parallel()
 
@@ -711,6 +798,42 @@ func TestSQLTransformerOptionIsUsedWhenCreatingTriggers(t *testing.T) {
 	})
 }
 
+func TestWithSearchPathOptionIsRespected(t *testing.T) {
+	t.Parallel()
+
+	opts := []roll.Option{roll.WithSearchPath("public")}
+
+	testutils.WithMigratorInSchemaAndConnectionToContainerWithOptions(t, "foo", opts, func(mig *roll.Roll, db *sql.DB) {
+		ctx := context.Background()
+
+		// Create a function in the public schema
+		_, err := db.ExecContext(ctx, `CREATE OR REPLACE FUNCTION say_hello()
+      RETURNS TEXT AS $$
+        SELECT 'hello world';
+      $$ LANGUAGE sql;
+    `)
+		require.NoError(t, err)
+
+		// Apply a migration in the foo schema that references the function in the public schema
+		err = mig.Start(ctx, &migrations.Migration{
+			Name: "01_raw_sql",
+			Operations: migrations.Operations{
+				&migrations.OpRawSQL{
+					Up: "SELECT say_hello()",
+				},
+			},
+		})
+		require.NoError(t, err)
+
+		// Complete the migration
+		err = mig.Complete(ctx)
+		require.NoError(t, err)
+
+		// No assertions required as the migration would have failed if the
+		// function reference was not found
+	})
+}
+
 func createTableOp(tableName string) *migrations.OpCreateTable {
 	return &migrations.OpCreateTable{
 		Name: tableName,
