@@ -6,6 +6,8 @@ import (
 	"context"
 	"database/sql"
 	"fmt"
+	"strings"
+	"time"
 
 	"github.com/lib/pq"
 
@@ -16,7 +18,11 @@ import (
 
 type PGVersion int
 
-const PGVersion15 PGVersion = 15
+const (
+	PGVersion15              PGVersion     = 15
+	DefaultBackfillBatchSize int           = 1000
+	DefaultBackfillDelay     time.Duration = 0
+)
 
 type Roll struct {
 	pgConn db.DB
@@ -27,17 +33,27 @@ type Roll struct {
 	// disable pgroll version schemas creation and deletion
 	disableVersionSchemas bool
 
+	// disable creation of version schema for raw SQL migrations
+	noVersionSchemaForRawSQL bool
+
 	migrationHooks MigrationHooks
 	state          *state.State
 	pgVersion      PGVersion
 	sqlTransformer migrations.SQLTransformer
+
+	backfillBatchSize  int
+	backfillBatchDelay time.Duration
 }
 
+// New creates a new Roll instance
 func New(ctx context.Context, pgURL, schema string, state *state.State, opts ...Option) (*Roll, error) {
 	rollOpts := &options{}
 	for _, o := range opts {
 		o(rollOpts)
 	}
+	if rollOpts.backfillBatchSize <= 0 {
+		rollOpts.backfillBatchSize = DefaultBackfillBatchSize
+	}
 
 	conn, err := setupConn(ctx, pgURL, schema, *rollOpts)
 	if err != nil {
@@ -45,7 +61,7 @@ func New(ctx context.Context, pgURL, schema string, state *state.State, opts ...
 	}
 
 	var pgMajorVersion PGVersion
-	err = conn.QueryRowContext(ctx, "SELECT split_part(split_part(version(), ' ', 2), '.', 1)").Scan(&pgMajorVersion)
+	err = conn.QueryRowContext(ctx, "SELECT substring(split_part(version(), ' ', 2) from '^[0-9]+')").Scan(&pgMajorVersion)
 	if err != nil {
 		return nil, fmt.Errorf("unable to retrieve postgres version: %w", err)
 	}
@@ -58,13 +74,16 @@ func New(ctx context.Context, pgURL, schema string, state *state.State, opts ...
 	}
 
 	return &Roll{
-		pgConn:                &db.RDB{DB: conn},
-		schema:                schema,
-		state:                 state,
-		pgVersion:             PGVersion(pgMajorVersion),
-		disableVersionSchemas: rollOpts.disableVersionSchemas,
-		migrationHooks:        rollOpts.migrationHooks,
-		sqlTransformer:        sqlTransformer,
+		pgConn:                   &db.RDB{DB: conn},
+		schema:                   schema,
+		state:                    state,
+		pgVersion:                pgMajorVersion,
+		sqlTransformer:           sqlTransformer,
+		disableVersionSchemas:    rollOpts.disableVersionSchemas,
+		noVersionSchemaForRawSQL: rollOpts.noVersionSchemaForRawSQL,
+		migrationHooks:           rollOpts.migrationHooks,
+		backfillBatchSize:        rollOpts.backfillBatchSize,
+		backfillBatchDelay:       rollOpts.backfillBatchDelay,
 	}, nil
 }
 
@@ -74,7 +93,8 @@ func setupConn(ctx context.Context, pgURL, schema string, options options) (*sql
 		dsn = pgURL
 	}
 
-	dsn += " search_path=" + schema
+	searchPath := append([]string{schema}, options.searchPath...)
+	dsn += " search_path=" + strings.Join(searchPath, ",")
 
 	conn, err := sql.Open("postgres", dsn)
 	if err != nil {
@@ -107,22 +127,27 @@ func setupConn(ctx context.Context, pgURL, schema string, options options) (*sql
 	return conn, nil
 }
 
+// Init initializes the Roll instance
 func (m *Roll) Init(ctx context.Context) error {
 	return m.state.Init(ctx)
 }
 
+// PGVersion returns the postgres version
 func (m *Roll) PGVersion() PGVersion {
 	return m.pgVersion
 }
 
+// PgConn returns the underlying database connection
 func (m *Roll) PgConn() db.DB {
 	return m.pgConn
 }
 
+// Schema returns the schema the Roll instance is acting on
 func (m *Roll) Schema() string {
 	return m.schema
 }
 
+// Status returns the current migration status
 func (m *Roll) Status(ctx context.Context, schema string) (*state.Status, error) {
 	return m.state.Status(ctx, schema)
 }
