@@ -70,22 +70,27 @@ LANGUAGE SQL
 STABLE;
 
 -- Get the name of the previous version of the schema, or NULL if there is none.
+-- This ignores previous versions for which no version schema exists, such as
+-- versions corresponding to inferred migrations.
 CREATE OR REPLACE FUNCTION %[1]s.previous_version(schemaname NAME) RETURNS text
 AS $$
-  WITH RECURSIVE find_ancestor AS (
-    SELECT schema, name, parent, migration_type FROM %[1]s.migrations
-      WHERE name = (SELECT %[1]s.latest_version(schemaname)) AND schema = schemaname
+  WITH RECURSIVE ancestors AS (
+  SELECT name, schema, parent, migration_type, 0 AS depth FROM %[1]s.migrations
+    WHERE name = %[1]s.latest_version(schemaname) AND schema = schemaname
 
-    UNION ALL
+  UNION ALL
 
-    SELECT m.schema, m.name, m.parent, m.migration_type FROM %[1]s.migrations m
-      INNER JOIN find_ancestor fa ON fa.parent = m.name AND fa.schema = m.schema
-      WHERE m.migration_type = 'inferred'
+  SELECT m.name, m.schema, m.parent, m.migration_type, a.depth + 1
+    FROM %[1]s.migrations m
+    JOIN ancestors a ON m.name = a.parent AND m.schema = a.schema
   )
-  SELECT a.parent
-  FROM find_ancestor AS a
-  JOIN %[1]s.migrations AS b ON a.parent = b.name AND a.schema = b.schema
-  WHERE b.migration_type = 'pgroll';
+  SELECT a.name FROM ancestors a
+    JOIN information_schema.schemata s
+    ON s.schema_name = schemaname || '_' || a.name
+    WHERE migration_type = 'pgroll'
+    AND a.depth > 0
+    ORDER by a.depth ASC
+    LIMIT 1;
 $$
 LANGUAGE SQL
 STABLE;
@@ -170,13 +175,15 @@ BEGIN
 				  SELECT COALESCE(json_object_agg(ix_details.name, json_build_object(
 				    'name', ix_details.name,
 				    'unique', ix_details.indisunique,
-				    'columns', ix_details.columns
+				    'columns', ix_details.columns,
+				    'predicate', ix_details.predicate
 				  )), '{}'::json)
 				  FROM (
 				    SELECT 
 				      replace(reverse(split_part(reverse(pi.indexrelid::regclass::text), '.', 1)), '"', '') as name,
 				      pi.indisunique,
-				      array_agg(a.attname) AS columns
+				      array_agg(a.attname) AS columns,
+				      pg_get_expr(pi.indpred, t.oid) AS predicate
 				    FROM pg_index pi
 				    JOIN pg_attribute a ON a.attrelid = pi.indrelid AND a.attnum = ANY(pi.indkey)
 				    WHERE indrelid = t.oid::regclass
@@ -276,7 +283,11 @@ BEGIN
 		RETURN;
 	END IF;
 
-	IF tg_event = 'sql_drop' and tg_tag != 'ALTER TABLE' THEN
+  IF tg_event = 'sql_drop' AND tg_tag = 'DROP SCHEMA' THEN
+    -- Take the schema name from the drop schema command
+    SELECT object_identity INTO schemaname FROM pg_event_trigger_dropped_objects();
+
+  ELSIF tg_event = 'sql_drop' and tg_tag != 'ALTER TABLE' THEN
 		-- Guess the schema from drop commands
 		SELECT schema_name INTO schemaname FROM pg_catalog.pg_event_trigger_dropped_objects() WHERE schema_name IS NOT NULL;
 
@@ -286,7 +297,11 @@ BEGIN
 			RETURN;
 		END IF;
 
-		SELECT schema_name INTO schemaname FROM pg_catalog.pg_event_trigger_ddl_commands() WHERE schema_name IS NOT NULL;
+		IF tg_tag = 'CREATE SCHEMA' THEN
+			SELECT object_identity INTO schemaname FROM pg_event_trigger_ddl_commands();
+		ELSE
+			SELECT schema_name INTO schemaname FROM pg_catalog.pg_event_trigger_ddl_commands() WHERE schema_name IS NOT NULL;
+		END IF;
 	END IF;
 
 	IF schemaname IS NULL THEN
@@ -298,10 +313,19 @@ BEGIN
 		RETURN;
 	END IF;
 
+	-- Remove any duplicate inferred migrations with the same timestamp for this
+	-- schema. We assume such migrations are multi-statement batched migrations
+	-- and we are only interested in the last one in the batch.
+	DELETE FROM %[1]s.migrations
+	WHERE schema = schemaname
+	AND created_at = current_timestamp
+	AND migration_type = 'inferred'
+	AND migration->'operations'->0->'sql'->>'up' = current_query();
+
 	-- Someone did a schema change without pgroll, include it in the history
 	SELECT INTO migration_id pg_catalog.format('sql_%%s',pg_catalog.substr(pg_catalog.md5(pg_catalog.random()::text), 0, 15));
 
-	INSERT INTO %[1]s.migrations (schema, name, migration, resulting_schema, done, parent, migration_type)
+	INSERT INTO %[1]s.migrations (schema, name, migration, resulting_schema, done, parent, migration_type, created_at, updated_at)
 	VALUES (
 		schemaname,
 		migration_id,
@@ -320,7 +344,9 @@ BEGIN
 		%[1]s.read_schema(schemaname),
 		true,
 		%[1]s.latest_version(schemaname),
-		'inferred'
+		'inferred',
+		statement_timestamp(),
+		statement_timestamp()
 	);
 END;
 $$;
@@ -367,6 +393,7 @@ func New(ctx context.Context, pgURL, stateSchema string) (*State, error) {
 	}, nil
 }
 
+// Init initializes the required pg_roll schema to store the state
 func (s *State) Init(ctx context.Context) error {
 	tx, err := s.pgConn.Begin()
 	if err != nil {
@@ -384,7 +411,7 @@ func (s *State) Init(ctx context.Context) error {
 	}
 
 	// Perform pgroll state initialization
-	_, err = tx.ExecContext(ctx, fmt.Sprintf(sqlInit, pq.QuoteIdentifier(s.schema)))
+	_, err = tx.ExecContext(ctx, fmt.Sprintf(sqlInit, pq.QuoteIdentifier(s.schema), pq.QuoteLiteral(s.schema)))
 	if err != nil {
 		return err
 	}
@@ -396,6 +423,7 @@ func (s *State) Close() error {
 	return s.pgConn.Close()
 }
 
+// Schema returns the schema name
 func (s *State) Schema() string {
 	return s.schema
 }
@@ -542,6 +570,7 @@ func (s *State) Complete(ctx context.Context, schema, name string) error {
 	return err
 }
 
+// ReadSchema reads the schema for the specified schema name
 func (s *State) ReadSchema(ctx context.Context, schemaName string) (*schema.Schema, error) {
 	var rawSchema []byte
 	err := s.pgConn.QueryRowContext(ctx, fmt.Sprintf("SELECT %s.read_schema($1)", s.schema), schemaName).Scan(&rawSchema)
