@@ -10,10 +10,10 @@ import (
 	"strings"
 	"sync"
 	"testing"
+	"time"
 
-	"github.com/google/go-cmp/cmp"
-	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"github.com/xataio/pgroll/pkg/migrations"
 	"github.com/xataio/pgroll/pkg/schema"
 	"github.com/xataio/pgroll/pkg/state"
@@ -197,6 +197,25 @@ func TestInferredMigration(t *testing.T) {
 					},
 				},
 			},
+			{
+				name: "create/drop schema",
+				sqlStmts: []string{
+					"CREATE SCHEMA foo",
+					"DROP SCHEMA foo",
+				},
+				wantMigrations: []migrations.Migration{
+					{
+						Operations: migrations.Operations{
+							&migrations.OpRawSQL{Up: "CREATE SCHEMA foo"},
+						},
+					},
+					{
+						Operations: migrations.Operations{
+							&migrations.OpRawSQL{Up: "DROP SCHEMA foo"},
+						},
+					},
+				},
+			},
 		}
 
 		for _, tt := range tests {
@@ -244,15 +263,62 @@ func TestInferredMigration(t *testing.T) {
 					assert.True(t, strings.HasPrefix(gotMigration.Name, "sql_") && len(gotMigration.Name) > 10)
 					gotMigration.Name = ""
 
-					if diff := cmp.Diff(wantMigration, gotMigration); diff != "" {
-						t.Errorf("expected schema mismatch (-want +got):\n%s", diff)
-					}
+					assert.Equal(t, wantMigration, gotMigration)
 				}
 			})
 		}
 	})
 }
 
+func TestInferredMigrationsInTransactionHaveDifferentTimestamps(t *testing.T) {
+	ctx := context.Background()
+
+	testutils.WithStateAndConnectionToContainer(t, func(state *state.State, db *sql.DB) {
+		// Start a transaction
+		tx, err := db.BeginTx(ctx, nil)
+		require.NoError(t, err)
+		defer tx.Rollback()
+
+		// Create two tables in the transaction
+		_, err = tx.ExecContext(ctx, "CREATE TABLE table1 (id int)")
+		require.NoError(t, err)
+
+		_, err = tx.ExecContext(ctx, "CREATE TABLE table2 (id int)")
+		require.NoError(t, err)
+
+		// Commit the transaction
+		tx.Commit()
+
+		// Read the migrations from the migrations table
+		rows, err := db.QueryContext(ctx,
+			fmt.Sprintf("SELECT name, created_at, updated_at FROM %s.migrations ORDER BY created_at ASC", state.Schema()))
+		if err != nil {
+			t.Fatal(err)
+		}
+		defer rows.Close()
+
+		type m struct {
+			name      string
+			createdAt time.Time
+			updatedAt time.Time
+		}
+		var migrations []m
+
+		for rows.Next() {
+			var migration m
+			if err := rows.Scan(&migration.name, &migration.createdAt, &migration.updatedAt); err != nil {
+				t.Fatal(err)
+			}
+
+			migrations = append(migrations, migration)
+		}
+
+		// Ensure that the two inferred migrations have different timestamps
+		assert.Equal(t, 2, len(migrations), "unexpected number of migrations")
+		assert.NotEqual(t, migrations[0].createdAt, migrations[1].createdAt, "migrations have the same timestamp")
+	})
+}
+
 func TestPgRollInitializationInANonDefaultSchema(t *testing.T) {
 	t.Parallel()
 
@@ -745,10 +811,17 @@ func TestReadSchema(t *testing.T) {
 				if err != nil {
 					t.Fatal(err)
 				}
-				if diff := cmp.Diff(tt.wantSchema, gotSchema, cmpopts.IgnoreFields(schema.Table{}, "OID")); diff != "" {
-					t.Errorf("expected schema mismatch (-want +got):\n%s", diff)
-				}
+				clearOIDS(gotSchema)
+				assert.Equal(t, tt.wantSchema, gotSchema)
 			})
 		}
 	})
 }
+
+func clearOIDS(s *schema.Schema) {
+	for k := range s.Tables {
+		c := s.Tables[k]
+		c.OID = ""
+		s.Tables[k] = c
+	}
+}
